@@ -23,25 +23,11 @@ import math
 import os.path
 import string
 
+from cairotextwriter import CairoTextWriter
+from gtkpixbuftextwriter import GtkPixbufTextWriter
+
 GCONF_DIR = "/apps/Maemo/advanced_clock_plugin/clock"
 
-def shift_unicode(string, offset):
-    ret = u""
-    for c in string :
-        if c != " " :
-            ret += unichr(ord(c.upper()) + offset)
-    return ret
-
-def to_klingon_digits(text):
-    text = string.replace(text, ".", "=")
-    text = string.replace(text, ":", "=")
-    text = string.replace(text, "/", "=")
-    text = string.replace(text, "-", "=")
-    return shift_unicode(text, 0xF8C0)
-
-def to_klingon_text(text):
-    return shift_unicode(text, 0xF88F)
-
 class Clock():
     def __init__(self, drawing_area, view_id = None):
         self.drawing_area = drawing_area
@@ -58,10 +44,25 @@ class Clock():
         self.init_gconf()
         self.load_gconf_settings()
 
+        if self.use_digit_images :
+            self.textwriter = GtkPixbufTextWriter(self.text_scaling, "/usr/lib/advanced-clock-plugin/digits/" + self.digit_image_set + "/")
+        else :
+            self.textwriter = CairoTextWriter(self.text_scaling, self.font_name, self.fill)
+
+    def calculate_text_width(self, text, font_size = 45):
+        return self.textwriter.calculate_text_width(text, font_size)
+
     def draw(self):
         self.time = datetime.today()
         self.context = self.drawing_area.window.cairo_create()
         self.context.select_font_face(self.font_name, cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_NORMAL)
+
+        self.drawable = self.drawing_area.window
+        self.fg_color = self.drawable.get_colormap().alloc(int(65535 * self.color_r), int(65535 * self.color_g), int(65535 * self.color_b))
+        self.gc = self.drawable.new_gc(foreground = self.fg_color)
+
+        self.textwriter.set_surfaces(self.context, self.drawable, self.gc)
+
         if self.resize_requested :
             self.resize()
             if self.alarm_enabled :
@@ -101,6 +102,9 @@ class Clock():
     def draw_clock(self):
         print "Implement draw_clock."
 
+    def draw_text(self, text, font_size = 45, x = 0, y = 35):
+        self.textwriter.draw_text(text, font_size, x, y)
+
 # The following method is currently only a placeholder/reminder 
 # and should not be used...
     def gconf_cb(self, client, conn_id, entry, args):
@@ -165,6 +169,10 @@ class Clock():
         if not self.gconf_client.get(GCONF_DIR + "/alarm_indicator_icon") :
             self.gconf_client.set_string(GCONF_DIR + "/alarm_indicator_icon", "")
 
+        if not self.gconf_client.get(GCONF_DIR + "/use_digit_images") :
+            self.gconf_client.set_bool(GCONF_DIR + "/use_digit_images", False)
+            self.gconf_client.set_string(GCONF_DIR + "/digit_image_set", "test-png")
+
     def load_gconf_settings(self):
         self.alarm_indicator_enabled = self.gconf_client.get_bool(self.gconf_dir + "/alarm_indicator_enabled")
         self.fill = self.gconf_client.get_bool(self.gconf_dir + "/fill")
@@ -195,6 +203,9 @@ class Clock():
         else:
             print "Image file does not exist: " + self.alarm_indicator_icon_file
 
+        self.use_digit_images = self.gconf_client.get_bool(self.gconf_dir + "/use_digit_images")
+        self.digit_image_set = self.gconf_client.get_string(self.gconf_dir + "/digit_image_set")
+
 # Currently we do not use the callback (see above).
 #        self.gconf_client.notify_add(GCONF_DIR, self.gconf_cb)
 
